import { requestData as request, jsonp } from '@ali/santa-fetch';
import Message from '@alife/dtux-message';

const get = (url, data) => request({
  url,
  method: 'GET',
  data,
  timeout: 0,
}).catch((error) => {
  Message.error('网络请求错误！');
  throw error;
});

let csrfToken;
const fetchCsrfTokenPromise = () => {
  if (!csrfToken) {
    csrfToken = request({
      url: '', // TODO 💰💰💰 修改获取 csrftoken 的接口地址
    }).then((info) => {
      if (!info || !info.headerName || !info.token) {
        throw new Error('CSRF Not Exist!');
      }
      return info || {};
    });
    setTimeout(() => {
      csrfToken = undefined;
    }, 11 * 1000); // 11s 之后失效，确保在过期前重新请求一次
  }
  return csrfToken;
};

const post = (url, data = {}, realHeaders = {}) => (fetchCsrfTokenPromise().then((info) => {
  const headers = {
    Accept: 'application/json',
    [info.headerName]: info.token,
    'Content-Type': realHeaders['Content-Type'] || 'application/x-www-form-urlencoded',
  };

  return request({
    url,
    method: 'POST',
    timeout: 0,
    data,
    headers,
  });
})).catch((error) => {
  Message.error('网络请求错误！');
  throw error;
});

const patch = (url, data) => request({
  url,
  method: 'PATCH',
  body: JSON.stringify(data),
});

const del = url => request({
  url,
  method: 'DELETE',
});

const put = (url, data) => request({
  url,
  method: 'PUT',
  body: JSON.stringify(data),
});

export default {
  request,
  get,
  post,
  patch,
  del,
  put,
  jsonp,
};
